"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.emit = void 0;
const Delimiters = require("../tokens/delimiters");
const GenericTokens = require("../tokens/generic_tokens");
const TypeReferenceTokens = require("../tokens/type_reference_tokens");
const MethodParameterTokens = require("../tokens/method_parameter_tokens");
const ModifierTokens = require("../tokens/modifier_tokens");
const ScopeEmitter = require("./scope_emitter");
function emit(writer, method) {
    emitDefinition(writer, method);
    emitBody(writer, method);
}
exports.emit = emit;
function emitDefinition(writer, method) {
    const { access, modifier, isAsync, result, name, generics, parameters } = method;
    writer
        .outputTabs()
        .write(...ModifierTokens.forAccess(access))
        .write(...ModifierTokens.forModifier(modifier))
        .write(...ModifierTokens.forAsync(isAsync))
        .write(...TypeReferenceTokens.emit(result))
        .write(Delimiters.space)
        .write(name)
        .write(...GenericTokens.emit(generics))
        .write(...MethodParameterTokens.emit(parameters))
        .writeLineNoTabs();
}
function emitBody(writer, method) {
    ScopeEmitter.emit(writer, writer => method.body.statements.forEach(s => writer.writeLine(s)));
}
